@@ -1,5 +1,5 @@
 /* variables.h -- Description of user visible variables in Info.
-   $Id: variables.h,v 1.7 2007/08/04 11:01:02 gray Exp $
+   $Id: variables.h,v 1.8 2008/02/26 16:51:06 karl Exp $
 
    This file is part of GNU Info, a program for reading online documentation
    stored in Info format.
@@ -41,7 +41,7 @@ typedef struct {
 /* Read the name of an Info variable in the echo area and return the
    address of a VARIABLE_ALIST member.  A return value of NULL indicates
    that no variable could be read. */
-extern VARIABLE_ALIST *read_variable_name (char *prompt, WINDOW *window);
+extern VARIABLE_ALIST *read_variable_name (const char *prompt, WINDOW *window);
 
 /* Make an array of REFERENCE which actually contains the names of the
    variables available in Info. */
